@@ -23,7 +23,7 @@
 
 #include <QObject>
 #include "typenames.h"
-#include "libgraphtheoryexport.h"
+#include "graphtheory_export.h"
 
 class QUrl;
 
